changeset 76710:13738aa5cbd1

Fix a comment before `current_minor_maps'.
author Eli Zaretskii <eliz@gnu.org>
date Sat, 24 Mar 2007 16:23:01 +0000
parents af7c3ea6462e
children ba2df4dce7bc
files src/keymap.c
diffstat 1 files changed, 4 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/src/keymap.c	Sat Mar 24 16:03:48 2007 +0000
+++ b/src/keymap.c	Sat Mar 24 16:23:01 2007 +0000
@@ -1401,8 +1401,10 @@
 static Lisp_Object *cmm_modes = NULL, *cmm_maps = NULL;
 static int cmm_size = 0;
 
-/* Store a pointer to an array of the keymaps of the currently active
-   minor modes in *buf, and return the number of maps it contains.
+/* Store a pointer to an array of the currently active minor modes in
+   *modeptr, a pointer to an array of the keymaps of the currently
+   active minor modes in *mapptr, and return the number of maps
+   *mapptr contains.
 
    This function always returns a pointer to the same buffer, and may
    free or reallocate it, so if you want to keep it for a long time or